@@ -2,7 +2,7 @@ package OpenGuides::Utils;
 
 use strict;
 use vars qw( $VERSION );
-$VERSION = '0.14';
+$VERSION = '0.15';
 
 use Carp qw( croak );
 use Wiki::Toolkit;
@@ -137,32 +137,15 @@ sub make_wiki_object {
         qr/\@INDEX_LIST\s+\[\[(Category|Locale)\s+([^\]]+)]]/ =>
              sub {
                    my ($wiki, $type, $value) = @_;
-
-                   # We may be being called by Wiki::Toolkit::Plugin::Diff,
-                   # which doesn't know it has to pass us $wiki
-                   unless ( UNIVERSAL::isa( $wiki, "Wiki::Toolkit" ) ) {
-                       return "(unprocessed INDEX_LIST macro)";
-		   }
-
-                   my @nodes = sort $wiki->list_nodes_by_metadata(
-                       metadata_type  => $type,
-                       metadata_value => $value,
-                       ignore_case    => 1,
-                   );
-                   unless ( scalar @nodes ) {
-                       return "\n* No pages currently in "
-                              . lc($type) . " $value\n";
-                   }
-                   my $return = "\n";
-                   foreach my $node ( @nodes ) {
-                       $return .= "* "
-                               . $wiki->formatter->format_link(
-                                                                wiki => $wiki,
-                                                                link => $node,
-                                                              )
-                                . "\n";
-	           }
-                   return $return;
+                   return $class->do_index_list_macro(
+                       wiki => $wiki, type => $type, value => $value,
+                       include_prefix => 1 );
+                 },
+        qr/\@INDEX_LIST_NO_PREFIX\s+\[\[(Category|Locale)\s+([^\]]+)]]/ =>
+             sub {
+                   my ($wiki, $type, $value) = @_;
+                   return $class->do_index_list_macro(
+                       wiki => $wiki, type => $type, value => $value );
                  },
         qr/\@MAP_LINK\s+\[\[(Category|Locale)\s+([^\]|]+)\|?([^\]]+)?\]\]/ =>
                 sub {
@@ -247,12 +230,14 @@ sub make_wiki_object {
         implicit_links      => 0,
         allowed_tags        => [qw(a p b strong i em pre small img table td
                                    tr th br hr ul li center blockquote kbd
-                                   div code strike sub sup font)],
+                                   div code span strike sub sup font dl dt dd
+                                  )],
         macros              => \%macros,
         pass_wiki_to_macros => 1,
         node_prefix         => "$script_name?",
         edit_prefix         => "$script_name?action=edit;id=",
         munge_urls          => 1,
+        external_link_class => "external",
     );
 
     my %conf = ( store     => $store,
@@ -263,6 +248,41 @@ sub make_wiki_object {
     return $wiki;
 }
 
+sub do_index_list_macro {
+    my ( $class, %args ) = @_;
+    my ( $wiki, $type, $value, $include_prefix )
+        = @args{ qw( wiki type value include_prefix ) };
+
+    # We may be being called by Wiki::Toolkit::Plugin::Diff,
+    # which doesn't know it has to pass us $wiki
+    if ( !UNIVERSAL::isa( $wiki, "Wiki::Toolkit" ) ) {
+        if ( $args{include_prefix} ) {
+            return "(unprocessed INDEX_LIST macro)";
+        } else {
+            return "(unprocessed INDEX_LIST_NO_PREFIX macro)";
+        }
+    }
+
+    my @nodes = sort $wiki->list_nodes_by_metadata(
+        metadata_type  => $type,
+        metadata_value => $value,
+        ignore_case    => 1,
+    );
+    unless ( scalar @nodes ) {
+        return "\n* No pages currently in " . lc($type) . " $value\n";
+    }
+    my $return = "\n";
+    foreach my $node ( @nodes ) {
+        my $title = $node;
+        $title =~ s/^(Category|Locale) // unless $args{include_prefix};
+        $return .= "* "
+                . $wiki->formatter->format_link( wiki => $wiki,
+                                                 link => "$node|$title" )
+                . "\n";
+    }
+    return $return;
+}
+
 =item B<get_wgs84_coords>
 
 Returns coordinate data suitable for use with Google Maps (and other GIS
@@ -386,6 +406,49 @@ sub get_wgs84_min_max {
     return %data;
 }
 
+=item B<get_index_page_description>
+
+    $tt_vars{page_description} =
+        OpenGuides::Utils->get_index_page_description(
+            format => "map",
+            criteria => [ type => "locale", value => "croydon" ],
+    );
+
+Returns a sentence that can be used as a summary of what's shown on an
+index page.
+
+=cut
+
+sub get_index_page_description {
+    my ( $class, %args ) = @_;
+    my $desc = ( $args{format} eq "map" ) ? "Map" : "List";
+    $desc .= " of all our pages";
+
+    my ( @cats, @locs );
+    foreach my $criterion ( @{$args{criteria}} ) {
+        my ( $type, $name ) = ( $criterion->{type}, $criterion->{name} );
+        if ( $type eq "category" ) {
+            $name =~ s/Category //;
+            push @cats, $name;
+        } else {
+            $name =~ s/Locale //;
+            push @locs, $name;
+        }
+    }
+
+    if ( scalar @cats ) {
+        $desc .= " labelled with: " . join( ", ", @cats );
+        if ( scalar @locs ) {
+            $desc .= ", and";
+        }
+    }
+    if ( scalar @locs ) {
+        $desc .= " located in: " . join( ", ", @locs );
+    }
+    $desc .= ".";
+    return $desc;
+}
+
 =item B<detect_redirect>
 
     $redir = OpenGuides::Utils->detect_redirect( content => "foo" );
